==> open-xchange-documents-backend_7.8.2.orig.tar.bz2: open-xchange-documents-backend-7.8.2/com.openexchange.office.odf/src/com/openexchange/office/odt/dom/Hyperlink.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.odt.dom;

import org.apache.xml.serializer.SerializationHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

import com.openexchange.office.odf.AttributesImpl;
import com.openexchange.office.odf.Namespaces;

public class Hyperlink implements Cloneable {

	private final AttributesImpl attributes;
	private final String nmsp;

	public Hyperlink(String nmsp) {
		attributes = new AttributesImpl();
		this.nmsp = nmsp;
	};

	public Hyperlink(String nmsp, Attributes attributes) {
		this.attributes = new AttributesImpl(attributes);
		this.nmsp = nmsp;
	}

	public String getStyleName() {
		return attributes.getValue("text:style-name");
	}

	public void setStyleName(String styleName) {
		// style-name only available within text namespace
		if(nmsp.equals(Namespaces.TEXT)) {
			attributes.setValue(Namespaces.TEXT, "text:style-name", "style-name", styleName);
		}
	}

	public String getHRef() {
		return attributes.getValue("xlink:href");
	}

	public void setHRef(String hRef) {
		attributes.setValue(Namespaces.XLINK, "xlink:href", "href", hRef);
	}

	public void writeAttributes(SerializationHandler output)
		throws SAXException {

		attributes.write(output);
	}

	public Hyperlink clone() {
		final Hyperlink hyperlink = new Hyperlink(nmsp);
		hyperlink.attributes.getMap().putAll(attributes.getMap());
		return hyperlink;
	}

	public void writeStartElement(SerializationHandler output)
		throws SAXException {

		if(nmsp.equals(Namespaces.TEXT)) {
			output.startElement(Namespaces.TEXT, "a", "text:a");
		}
		else if(nmsp.equals(Namespaces.DRAW)) {
			output.startElement(Namespaces.DRAW, "a", "draw:a");
		}
	}

	public void writeEndElement(SerializationHandler output)
		throws SAXException {

		if(nmsp.equals(Namespaces.TEXT)) {
			output.endElement(Namespaces.TEXT, "a", "text:a");
		}
		else if(nmsp.equals(Namespaces.DRAW)) {
			output.endElement(Namespaces.DRAW, "a", "draw:a");
		}
	}
}

==> open-xchange-documents-backend_7.8.3.orig.tar.bz2: open-xchange-documents-backend-7.8.3/com.openexchange.office.odf/src/com/openexchange/office/odt/dom/Hyperlink.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.odt.dom;

import org.apache.xml.serializer.SerializationHandler;
import org.xml.sax.SAXException;

import com.openexchange.office.odf.AttributesImpl;
import com.openexchange.office.odf.Namespaces;
import com.openexchange.office.odf.SaxContextHandler;

public class Hyperlink implements Cloneable {

	private final AttributesImpl attributesImpl;
	private final String nmsp;

	public Hyperlink(String nmsp) {
		attributesImpl = new AttributesImpl();
		this.nmsp = nmsp;
	};

	public Hyperlink(String nmsp, AttributesImpl attributesImpl) {
		this.attributesImpl = attributesImpl;
		this.nmsp = nmsp;
	}

	public String getStyleName() {
		return attributesImpl.getValue("text:style-name");
	}

	public void setStyleName(String styleName) {
		// style-name only available within text namespace
		if(nmsp.equals(Namespaces.TEXT)) {
			attributesImpl.setValue(Namespaces.TEXT, "style-name", "text:style-name", styleName);
		}
	}

	public String getHRef() {
		return attributesImpl.getValue("xlink:href");
	}

	public void setHRef(String hRef) {
		attributesImpl.setValue(Namespaces.XLINK, "href", "xlink:href", hRef);
	}

	public void writeAttributes(SerializationHandler output)
		throws SAXException {

		attributesImpl.write(output);
	}

	public Hyperlink clone() {
		return new Hyperlink(nmsp, attributesImpl.clone());
	}

	public void writeStartElement(SerializationHandler output)
		throws SAXException {

		if(nmsp.equals(Namespaces.TEXT)) {
			SaxContextHandler.startElement(output, Namespaces.TEXT, "a", "text:a");
		}
		else if(nmsp.equals(Namespaces.DRAW)) {
			SaxContextHandler.startElement(output, Namespaces.DRAW, "a", "draw:a");
		}
	}

	public void writeEndElement(SerializationHandler output)
		throws SAXException {

		if(nmsp.equals(Namespaces.TEXT)) {
			SaxContextHandler.endElement(output, Namespaces.TEXT, "a", "text:a");
		}
		else if(nmsp.equals(Namespaces.DRAW)) {
			SaxContextHandler.endElement(output, Namespaces.DRAW, "a", "draw:a");
		}
	}
}
